RDFFormats.FormatWriters.DOMWriter

Package RDFFormats :: Module FormatWriters :: Class DOMWriter |
[show private | hide private]
[frames | no frames]

## Class DOMWriter

Known Subclasses:
  `DOMWriter`

    A DOM document writer.

Method Summary
| ``__init__`(self, doc, root, qualifier, value_as_attribute)` Initialise the writer with the document 'doc' to be written to, the element 'root' within which information is to be inserted.
| `close(self)`
| `end_element(self, label)`
| `get_item_type_name(self, label)`
| `get_property_label(self, property_name)`
| `get_property_name(self, attribute_name)`
| `start_element(self, label)`
| `write_attribute(self, name, modifiers, value, subvalues, multivalues)`

Method Details

### __init__(self, doc, root, qualifier, value_as_attribute=0) (Constructor)
    Initialise the writer with the document 'doc' to be written to, the
    element 'root' within which information is to be inserted. The following
    parameters configure the writer:

      * qualifier           - use a specific qualifier, given as a 2-tuple
                              of the form (namespace, prefix), on elements
                              added to the document
      * value_as_attribute  - write values as attributes on elements (or
                              write them as text within the elements, as is
                              the default, false value for this parameter)

Generated by Epydoc 2.1 on Sat Jul 7 19:42:53 2007 | http://epydoc.sf.net